Module pxe

Module pxe 

This defines Pxe / Pfn types that makes it easier to manipulate PFNs and PXEs.

Examples

let pxe = Pxe::new(
    Pfn::new(0x6d600),
    PxeFlags::USER_ACCESSIBLE | PxeFlags::ACCESSED | PxeFlags::PRESENT
);
let encoded = u64::from(pxe);
let decoded = Pxe::from(encoded);

Structs

Pfn
Strong type for a Page Frame Number.
Pxe
A Pxe is a set of flags (PxeFlags) and a Page Frame Number (PFN).
PxeFlags
The various bits and flags that a Pxe has.